@@ -415,7 +415,7 @@ def functional_NComponent():
     print("$$ F = \\int_\\Omega (f_{int} + f_{bulk} + f_{well} + f_{ori} + f_{q2} + \\lambda(1-\\sqrt{\\sum q_i^2}) $$")
     print("$$ f_{int} = \\frac{\\epsilon_\\phi^2\\eta T}{2}|\\nabla \\phi|^2 $$")
     print("$$ f_{bulk} = G_L(\\textbf{c}, T) + h(\\phi)(G_S(\\textbf{c}, T) - G_L(\\textbf{c}, T)) $$")
-    print("$$ f_{well} = \\sum_i c_iW_ig(\\phi) $$
+    print("$$ f_{well} = \\sum_i c_iW_ig(\\phi) $$")
     print("$$ f_{ori} = 2HTp(\\phi)|\\nabla \\textbf{q}| $$")
     print("$$ f_{q2} = \\frac{\\epsilon_q^2}{2}|\\nabla \\textbf{q}|^2 $$")
     print("$$ h(\\phi) = \\phi^3(6\\phi^2 - 15\\phi + 10) $$")
