@@ -1,3 +1,3 @@
 from .Diffusion import Diffusion, init_Diffusion
 from .Warren1995 import Warren1995, init_Warren1995
-from .NComponent import NComponent, init_NComponent
\ No newline at end of file
+from .NComponent import engine_NComponent, init_NComponent
\ No newline at end of file
